from a10sdk.common.A10BaseClass import A10BaseClass


class Bfd(A10BaseClass):
    
    """Class Description::
    Bidirectional Forwarding Detection.

    Class bfd supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param bfd_ipv6_list: {"minItems": 1, "items": {"type": "bfd-ipv6"}, "uniqueItems": true, "array": [{"required": ["local-ipv6", "nexthop-ipv6"], "properties": {"local-ipv6": {"optional": false, "type": "string", "description": "Local IPv6 address", "format": "ipv6-address"}, "nexthop-ipv6": {"optional": false, "type": "string", "description": "Nexthop IPv6 address", "format": "ipv6-address"}}}], "type": "array", "$ref": "/axapi/v3/ipv6/route/static/bfd/bfd-ipv6/{local-ipv6}+{nexthop-ipv6}"}
    :param ethernet_list: {"minItems": 1, "items": {"type": "ethernet"}, "uniqueItems": true, "array": [{"required": ["eth-num", "nexthop-ipv6-ll"], "properties": {"eth-num": {"optional": false, "type": "number", "description": "Ethernet (not a member of vlan or trunk)", "format": "number"}, "nexthop-ipv6-ll": {"optional": false, "type": "string", "description": "Nexthop IPv6 address (Link-local)", "format": "ipv6-address"}}}], "type": "array", "$ref": "/axapi/v3/ipv6/route/static/bfd/ethernet/{eth-num}+{nexthop-ipv6-ll}"}
    :param trunk_list: {"minItems": 1, "items": {"type": "trunk"}, "uniqueItems": true, "array": [{"required": ["trunk-num", "nexthop-ipv6-ll"], "properties": {"nexthop-ipv6-ll": {"optional": false, "type": "string", "description": "Nexthop IPv6 address (Link-local)", "format": "ipv6-address"}, "trunk-num": {"optional": false, "type": "number", "description": "Trunk interface", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/ipv6/route/static/bfd/trunk/{trunk-num}+{nexthop-ipv6-ll}"}
    :param ve_list: {"minItems": 1, "items": {"type": "ve"}, "uniqueItems": true, "array": [{"required": ["ve-num", "nexthop-ipv6-ll"], "properties": {"nexthop-ipv6-ll": {"optional": false, "type": "string", "description": "Nexthop IPv6 address (Link-local)", "format": "ipv6-address"}, "ve-num": {"optional": false, "type": "number", "description": "Virtual ethernet interface", "format": "number"}}}], "type": "array", "$ref": "/axapi/v3/ipv6/route/static/bfd/ve/{ve-num}+{nexthop-ipv6-ll}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ipv6/route/static/bfd`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "bfd"
        self.a10_url="/axapi/v3/ipv6/route/static/bfd"
        self.DeviceProxy = ""
        self.bfd_ipv6_list = []
        self.ethernet_list = []
        self.trunk_list = []
        self.ve_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param hits: {"description": "Number of times the IP was selected", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.hits = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IpServer(A10BaseClass):
    
    """Class Description::
    Statistics for the object ip-server.

    Class ip-server supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ip_server_name: {"description": "Specify the real server name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/site/{site_name}/ip-server/{ip_server_name}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ip_server_name"]

        self.b_key = "ip-server"
        self.a10_url="/axapi/v3/gslb/site/{site_name}/ip-server/{ip_server_name}/stats"
        self.DeviceProxy = ""
        self.ip_server_name = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param max_outstanding_request_count: {"description": "Max queued request count", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "2"}
    :param failure_count: {"description": "Total failure count", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "2"}
    :param response_count: {"description": "Total response count", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "2"}
    :param ring_full_count: {"description": "Compression queue full", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "2"}
    :param submit_count: {"description": "Total submit count", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "2"}
    :param request_count: {"description": "Total request count", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "2"}
    :param max_outstanding_submit_count: {"description": "Max queued submit count", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "2"}
    :param failure_code: {"description": "Last failure code", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "2"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.max_outstanding_request_count = ""
        self.failure_count = ""
        self.response_count = ""
        self.ring_full_count = ""
        self.submit_count = ""
        self.request_count = ""
        self.max_outstanding_submit_count = ""
        self.failure_code = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class HwCompress(A10BaseClass):
    
    """Class Description::
    Statistics for the object hw-compress.

    Class hw-compress supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/hw-compress/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "hw-compress"
        self.a10_url="/axapi/v3/slb/hw-compress/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class IpNatMapList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param floating_IP_forward_address: {"type": "string", "description": "Floating-IP as forward address. help-val Address", "format": "ipv4-address"}
    :param ip_nat_prefix: {"type": "string", "description": "Address", "format": "ipv4-cidr"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-nat-map-list"
        self.DeviceProxy = ""
        self.floating_IP_forward_address = ""
        self.ip_nat_prefix = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class IpNatMap(A10BaseClass):
    
    """Class Description::
    IP NAT redistribution map.

    Class ip-nat-map supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ip_nat_map_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"floating-IP-forward-address": {"type": "string", "description": "Floating-IP as forward address. help-val Address", "format": "ipv4-address"}, "optional": true, "ip-nat-prefix": {"type": "string", "description": "Address", "format": "ipv4-cidr"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/ospf/{process_id}/redistribute/ip-nat/ip-nat-map`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ip-nat-map"
        self.a10_url="/axapi/v3/router/ospf/{process_id}/redistribute/ip-nat/ip-nat-map"
        self.DeviceProxy = ""
        self.ip_nat_map_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class UdldTimeoutCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param slow: {"description": "slow timeout in unit of seconds", "format": "number", "default": 1, "maximum": 60, "minimum": 1, "not": "fast", "type": "number"}
    :param fast: {"description": "fast timeout in unit of milli-seconds", "format": "number", "default": 1000, "maximum": 1000, "minimum": 100, "not": "slow", "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "udld-timeout-cfg"
        self.DeviceProxy = ""
        self.slow = ""
        self.fast = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TrunkGroup(A10BaseClass):
    
    """Class Description::
    Trunk Group Settings.

    Class trunk-group supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param trunk_number: {"description": "Trunk Number", "format": "number", "type": "number", "maximum": 16, "minimum": 1, "optional": false}
    :param mode: {"description": "'active': enable initiation of LACP negotiation on a port(default); 'passive': disable initiation of LACP negotiation on a port; ", "format": "enum", "default": "active", "type": "string", "enum": ["active", "passive"], "optional": true}
    :param timeout: {"description": "'long': Set LACP long timeout (default); 'short': Set LACP short timeout; ", "format": "enum", "default": "long", "type": "string", "enum": ["long", "short"], "optional": true}
    :param type: {"description": "'static': Static (default); 'lacp': lacp; 'lacp-udld': lacp-udld; ", "format": "enum", "default": "static", "optional": true, "enum": ["static", "lacp", "lacp-udld"], "modify-not-allowed": 1, "type": "string"}
    :param admin_key: {"description": "LACP admin key (Admin key value)", "format": "number", "type": "number", "maximum": 65535, "minimum": 10000, "optional": true}
    :param port_priority: {"description": "Set LACP priority for a port (LACP port priority)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/ethernet/{ifnum}/trunk-group/{trunk_number}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "trunk_number"]

        self.b_key = "trunk-group"
        self.a10_url="/axapi/v3/interface/ethernet/{ifnum}/trunk-group/{trunk_number}"
        self.DeviceProxy = ""
        self.trunk_number = ""
        self.udld_timeout_cfg = {}
        self.mode = ""
        self.timeout = ""
        self.A10WW_type = ""
        self.admin_key = ""
        self.port_priority = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class BroadcastRateLimit(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param rate: {"description": "packets per second. Default is 500. (packets per second. Please specify an even number. Default is 500)", "format": "number", "default": 500, "maximum": 5000, "minimum": 50, "type": "number"}
    :param bcast_rate_limit_enable: {"default": 0, "type": "number", "description": "Rate limit the l2 broadcast packet on mgmt port", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "broadcast-rate-limit"
        self.DeviceProxy = ""
        self.rate = ""
        self.bcast_rate_limit_enable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param inbound: {"default": 0, "type": "number", "description": "ACL applied on incoming packets to this interface", "format": "flag"}
    :param address_type: {"enum": ["link-local"], "type": "string", "description": "'link-local': Configure an IPv6 link local address; ", "format": "enum"}
    :param default_ipv6_gateway: {"type": "string", "description": "Set default gateway (Default gateway address)", "format": "ipv6-address"}
    :param ipv6_addr: {"type": "string", "description": "Set the IPv6 address of an interface", "format": "ipv6-address-plen"}
    :param v6_acl_name: {"description": "Apply ACL rules to incoming packets on this interface (Named Access List)", "format": "string", "minLength": 1, "maxLength": 32, "type": "string", "$ref": "/axapi/v3/ipv6/access-list"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv6"
        self.DeviceProxy = ""
        self.inbound = ""
        self.address_type = ""
        self.default_ipv6_gateway = ""
        self.ipv6_addr = ""
        self.v6_acl_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ip(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dhcp: {"default": 0, "not": "ipv4-address", "type": "number", "description": "Use DHCP to configure IP address", "format": "flag"}
    :param ipv4_address: {"not": "dhcp", "type": "string", "description": "IP address", "format": "ipv4-address"}
    :param default_gateway: {"type": "string", "description": "Set default gateway (Default gateway address)", "format": "ipv4-address"}
    :param control_apps_use_mgmt_port: {"default": 0, "type": "number", "description": "Control applications use management port", "format": "flag"}
    :param ipv4_netmask: {"type": "string", "description": "IP subnet mask", "format": "ipv4-netmask"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip"
        self.DeviceProxy = ""
        self.dhcp = ""
        self.ipv4_address = ""
        self.default_gateway = ""
        self.control_apps_use_mgmt_port = ""
        self.ipv4_netmask = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AccessList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param acl_name: {"minLength": 1, "maxLength": 16, "type": "string", "description": "Apply an access list (Named Access List)", "format": "string"}
    :param acl_id: {"description": "ACL id", "format": "number", "maximum": 199, "minimum": 1, "type": "number", "$ref": "/axapi/v3/access-list/standard"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "access-list"
        self.DeviceProxy = ""
        self.acl_name = ""
        self.acl_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Management(A10BaseClass):
    
    """Class Description::
    Management interface.

    Class management supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param duplexity: {"description": "'Full': Full; 'Half': Half; 'auto': Auto; ", "format": "enum", "default": "auto", "type": "string", "enum": ["Full", "Half", "auto"], "optional": true}
    :param speed: {"description": "'10': 10 Mbs/sec; '100': 100 Mbs/sec; '1000': 1 Gb/sec; 'auto': Auto Negotiate Speed;  (Interface Speed)", "format": "enum", "default": "auto", "type": "string", "enum": ["10", "100", "1000", "auto"], "optional": true}
    :param action: {"optional": true, "enum": ["enable", "disable"], "type": "string", "description": "'enable': Enable Management Port; 'disable': Disable Management Port; ", "format": "enum"}
    :param flow_control: {"default": 0, "optional": true, "type": "number", "description": "Enable 802.3x flow control on full duplex port", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/management`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "management"
        self.a10_url="/axapi/v3/interface/management"
        self.DeviceProxy = ""
        self.lldp = {}
        self.broadcast_rate_limit = {}
        self.duplexity = ""
        self.speed = ""
        self.ipv6 = {}
        self.action = ""
        self.ip = {}
        self.access_list = {}
        self.flow_control = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Rules(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param le: {"description": "Maximum prefix length to be matched", "minimum": 0, "type": "number", "maximum": 32, "format": "number"}
    :param description: {"minLength": 1, "maxLength": 80, "type": "string", "description": "Prefix-list specific description (Up to 80 characters describing this prefix-list)", "format": "string"}
    :param seq: {"description": "Sequence number of an entry", "minimum": 1, "type": "number", "maximum": 4294967295, "format": "number"}
    :param ipaddr: {"type": "string", "description": "IP prefix, e.g., 35.0.0.0/8", "format": "ipv4-cidr"}
    :param ge: {"description": "Minimum prefix length to be matched", "minimum": 0, "type": "number", "maximum": 32, "format": "number"}
    :param action: {"enum": ["deny", "permit"], "type": "string", "description": "'deny': Specify packets to reject; 'permit': Specify packets to forward; ", "format": "enum"}
    :param any: {"default": 0, "type": "number", "description": "Any prefix match. Same as \"0.0.0.0/0 le 32\"", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "rules"
        self.DeviceProxy = ""
        self.le = ""
        self.description = ""
        self.seq = ""
        self.ipaddr = ""
        self.ge = ""
        self.action = ""
        self.A10WW_any = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PrefixList(A10BaseClass):
    
    """Class Description::
    Configure Prefix-list.

    Class prefix-list supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param rules: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"le": {"description": "Maximum prefix length to be matched", "minimum": 0, "type": "number", "maximum": 32, "format": "number"}, "description": {"minLength": 1, "maxLength": 80, "type": "string", "description": "Prefix-list specific description (Up to 80 characters describing this prefix-list)", "format": "string"}, "seq": {"description": "Sequence number of an entry", "minimum": 1, "type": "number", "maximum": 4294967295, "format": "number"}, "ipaddr": {"type": "string", "description": "IP prefix, e.g., 35.0.0.0/8", "format": "ipv4-cidr"}, "ge": {"description": "Minimum prefix length to be matched", "minimum": 0, "type": "number", "maximum": 32, "format": "number"}, "action": {"enum": ["deny", "permit"], "type": "string", "description": "'deny': Specify packets to reject; 'permit': Specify packets to forward; ", "format": "enum"}, "optional": true, "any": {"default": 0, "type": "number", "description": "Any prefix match. Same as \"0.0.0.0/0 le 32\"", "format": "flag"}}}]}
    :param name: {"description": "Name of a prefix list", "format": "string", "minLength": 1, "optional": false, "maxLength": 128, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/prefix-list/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "prefix-list"
        self.a10_url="/axapi/v3/ip/prefix-list/{name}"
        self.DeviceProxy = ""
        self.rules = []
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ClassList(A10BaseClass):
    
    """Class Description::
    Classification list.

    Class class-list supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param lid_list: {"minItems": 1, "items": {"type": "lid"}, "uniqueItems": true, "array": [{"required": ["lidnum"], "properties": {"over-limit-action": {"default": 0, "optional": true, "type": "number", "description": "Action when exceeds limit", "format": "flag"}, "log": {"default": 0, "optional": true, "type": "number", "description": "Log a message", "format": "flag"}, "lidnum": {"description": "Specify a limit ID", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": false}, "action-value": {"optional": true, "enum": ["dns-cache-disable", "dns-cache-enable", "forward"], "type": "string", "description": "'dns-cache-disable': Disable DNS cache when it exceeds limit; 'dns-cache-enable': Enable DNS cache when it exceeds limit; 'forward': Forward the traffic even it exceeds limit; ", "format": "enum"}, "per": {"description": "Per (Number of 100ms)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "lockout": {"description": "Don't accept any new connection for certain time (Lockout duration in minutes)", "format": "number", "type": "number", "maximum": 1023, "minimum": 1, "optional": true}, "dns": {"type": "object", "properties": {"cache-action": {"default": "cache-disable", "enum": ["cache-disable", "cache-enable"], "type": "string", "description": "'cache-disable': Disable dns cache; 'cache-enable': Enable dns cache; ", "format": "enum"}, "weight": {"description": "Weight for cache entry", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "ttl": {"description": "TTL for cache entry (TTL in seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}}}, "conn-rate-limit": {"description": "Connection rate limit", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}, "log-interval": {"description": "Log interval (minute, by default system will log every over limit instance)", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/template/dns/{name}/class-list/lid/{lidnum}"}
    :param name: {"description": "Specify a class list name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/template/dns/{name}/class-list`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "class-list"
        self.a10_url="/axapi/v3/cgnv6/template/dns/{name}/class-list"
        self.DeviceProxy = ""
        self.lid_list = []
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SslSid(A10BaseClass):
    
    """Class Description::
    SSL session ID  persistence.

    Class ssl-sid supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param dont_honor_conn_rules: {"default": 0, "optional": true, "type": "number", "description": "Do not observe connection rate rules", "format": "flag"}
    :param name: {"description": "SSL session ID persistence template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param timeout: {"description": "Persistence timeout (in minutes)", "format": "number", "type": "number", "maximum": 2000, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/persist/ssl-sid/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "ssl-sid"
        self.a10_url="/axapi/v3/slb/template/persist/ssl-sid/{name}"
        self.DeviceProxy = ""
        self.dont_honor_conn_rules = ""
        self.name = ""
        self.timeout = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Pptp(A10BaseClass):
    
    """Class Description::
    PPTP ALG Settings.

    Class pptp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param pptp: {"description": "'disable': Disable PPTP NAT ALG; 'enable': Enable PPTP NAT ALG; ", "format": "enum", "default": "disable", "type": "string", "enum": ["disable", "enable"], "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/nat/alg/pptp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "pptp"
        self.a10_url="/axapi/v3/ip/nat/alg/pptp"
        self.DeviceProxy = ""
        self.pptp = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ipv4Routes(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Distance: {"type": "number", "format": "number"}
    :param Interface: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Metric: {"type": "number", "format": "number"}
    :param Nexthop: {"type": "string", "format": "ipv4-address"}
    :param Subtype: {"enum": ["inter-area", "nssa-type-1", "nssa-type-2", "external-type-1", "external-type-2", "level-1", "level-2"], "type": "string", "format": "enum"}
    :param Prefix: {"type": "string", "format": "ipv4-address"}
    :param PrefixLen: {"type": "number", "format": "number"}
    :param Type: {"enum": ["kernel", "connected", "static", "rip", "ospf", "bgp", "isis", "vip", "selected-vip", "ip-nat-list", "ip-nat", "floating-ip", "a10"], "type": "string", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "IPv4-routes"
        self.DeviceProxy = ""
        self.Distance = ""
        self.Interface = ""
        self.Metric = ""
        self.Nexthop = ""
        self.Subtype = ""
        self.Prefix = ""
        self.PrefixLen = ""
        self.Type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Total: {"type": "number", "format": "number"}
    :param Limit: {"type": "number", "format": "number"}
    :param Description: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string-rlx"}
    :param IPv4_routes: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"Distance": {"type": "number", "format": "number"}, "Interface": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true, "Metric": {"type": "number", "format": "number"}, "Nexthop": {"type": "string", "format": "ipv4-address"}, "Subtype": {"enum": ["inter-area", "nssa-type-1", "nssa-type-2", "external-type-1", "external-type-2", "level-1", "level-2"], "type": "string", "format": "enum"}, "Prefix": {"type": "string", "format": "ipv4-address"}, "PrefixLen": {"type": "number", "format": "number"}, "Type": {"enum": ["kernel", "connected", "static", "rip", "ospf", "bgp", "isis", "vip", "selected-vip", "ip-nat-list", "ip-nat", "floating-ip", "a10"], "type": "string", "format": "enum"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.Total = ""
        self.Limit = ""
        self.Description = ""
        self.IPv4_routes = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Rib(A10BaseClass):
    
    """Class Description::
    Operational Status for the object rib.

    Class rib supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/rib/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "rib"
        self.a10_url="/axapi/v3/ip/rib/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param hit: {"description": "Total cache hit", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "2"}
    :param ageout_weight: {"description": "Total aged for lower weight", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "2"}
    :param answer_r: {"description": "Response with multiple answers", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "2"}
    :param multiple_r: {"description": "Response with multiple questions", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "2"}
    :param multiple_q: {"description": "Query with multiple questions", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "2"}
    :param total_alloc: {"description": "Total allocated", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "2"}
    :param current_allocate: {"description": "Current allocate", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param bad_q: {"description": "Query not passed", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "2"}
    :param bad_answer: {"description": "Bad Answer", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "2"}
    :param total_freed: {"description": "Total freed", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "2"}
    :param bad_r: {"description": "Response not passed", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "2"}
    :param encode_r: {"description": "Response encoded", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "2"}
    :param encode_q: {"description": "Query encoded", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "2"}
    :param ageout: {"description": "Total aged out", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "2"}
    :param total_q: {"description": "Total query", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "2"}
    :param total_r: {"description": "Total server response", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "2"}
    :param total_log: {"description": "Total stats log sent", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "2"}
    :param oversize_r: {"description": "Response exceed cache size", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "2"}
    :param current_data_allocate: {"description": "Current data allocate", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param ttl_r: {"description": "Response with short TTL", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "2"}
    :param oversize_q: {"description": "Query exceed cache size", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "2"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.hit = ""
        self.ageout_weight = ""
        self.answer_r = ""
        self.multiple_r = ""
        self.multiple_q = ""
        self.total_alloc = ""
        self.current_allocate = ""
        self.bad_q = ""
        self.bad_answer = ""
        self.total_freed = ""
        self.bad_r = ""
        self.encode_r = ""
        self.encode_q = ""
        self.ageout = ""
        self.total_q = ""
        self.total_r = ""
        self.total_log = ""
        self.oversize_r = ""
        self.current_data_allocate = ""
        self.ttl_r = ""
        self.oversize_q = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DnsCache(A10BaseClass):
    
    """Class Description::
    Statistics for the object dns-cache.

    Class dns-cache supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/dns-cache/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "dns-cache"
        self.a10_url="/axapi/v3/slb/dns-cache/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SshPubkey(A10BaseClass):
    
    """Class Description::
    Config openssh authorized public keys management.

    Class ssh-pubkey supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param import: {"default": 0, "optional": true, "type": "number", "description": "Import an authorized public key", "format": "flag"}
    :param list: {"default": 0, "optional": true, "type": "number", "description": "List all authorized public keys", "format": "flag"}
    :param file_url: {"optional": true, "type": "string", "description": "File URL", "format": "url"}
    :param use_mgmt_port: {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}
    :param delete: {"description": "Delete an authorized public key (SSH key index)", "format": "number", "type": "number", "maximum": 1000000, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/admin/{user}/ssh-pubkey`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ssh-pubkey"
        self.a10_url="/axapi/v3/admin/{user}/ssh-pubkey"
        self.DeviceProxy = ""
        self.A10WW_import = ""
        self.A10WW_list = ""
        self.file_url = ""
        self.use_mgmt_port = ""
        self.delete = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ve(A10BaseClass):
    
    """Class Description::
    Virtual ethernet interface.

    Class ve supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param nexthop_ipv6_ll: {"optional": false, "type": "string", "description": "Nexthop IPv6 address (Link-local)", "format": "ipv6-address"}
    :param ve_num: {"optional": false, "type": "number", "description": "Virtual ethernet interface", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ipv6/route/static/bfd/ve/{ve_num}+{nexthop_ipv6_ll}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ve_num","nexthop_ipv6_ll"]

        self.b_key = "ve"
        self.a10_url="/axapi/v3/ipv6/route/static/bfd/ve/{ve_num}+{nexthop_ipv6_ll}"
        self.DeviceProxy = ""
        self.nexthop_ipv6_ll = ""
        self.ve_num = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Record(A10BaseClass):
    
    """Class Description::
    Configure record types to be exported.

    Class record supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param sesn_event_nat64: {"optional": true, "enum": ["both", "creation", "deletion"], "type": "string", "description": "'both': Export both creation and deletion events; 'creation': Export only creation events; 'deletion': Export only deletion events; ", "format": "enum"}
    :param nat64: {"default": 0, "optional": true, "type": "number", "description": "NAT64 Flow Record Template", "format": "flag"}
    :param dslite: {"default": 0, "optional": true, "type": "number", "description": "DS-Lite Flow Record Template", "format": "flag"}
    :param nat44: {"default": 0, "optional": true, "type": "number", "description": "NAT44 Flow Record Template", "format": "flag"}
    :param netflow_v5_ext: {"default": 0, "optional": true, "type": "number", "description": "Extended NetFlow V5 Flow Record Template, supports ipv6", "format": "flag"}
    :param port_mapping_nat64: {"optional": true, "enum": ["both", "creation", "deletion"], "type": "string", "description": "'both': Export both creation and deletion events; 'creation': Export only creation events; 'deletion': Export only deletion events; ", "format": "enum"}
    :param sesn_event_dslite: {"optional": true, "enum": ["both", "creation", "deletion"], "type": "string", "description": "'both': Export both creation and deletion events; 'creation': Export only creation events; 'deletion': Export only deletion events; ", "format": "enum"}
    :param sesn_event_nat44: {"optional": true, "enum": ["both", "creation", "deletion"], "type": "string", "description": "'both': Export both creation and deletion events; 'creation': Export only creation events; 'deletion': Export only deletion events; ", "format": "enum"}
    :param netflow_v5: {"default": 0, "optional": true, "type": "number", "description": "NetFlow V5 Flow Record Template", "format": "flag"}
    :param port_mapping_dslite: {"optional": true, "enum": ["both", "creation", "deletion"], "type": "string", "description": "'both': Export both creation and deletion events; 'creation': Export only creation events; 'deletion': Export only deletion events; ", "format": "enum"}
    :param port_mapping_nat44: {"optional": true, "enum": ["both", "creation", "deletion"], "type": "string", "description": "'both': Export both creation and deletion events; 'creation': Export only creation events; 'deletion': Export only deletion events; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/netflow/monitor/{name}/record`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "record"
        self.a10_url="/axapi/v3/netflow/monitor/{name}/record"
        self.DeviceProxy = ""
        self.sesn_event_nat64 = ""
        self.nat64 = ""
        self.dslite = ""
        self.nat44 = ""
        self.netflow_v5_ext = ""
        self.port_mapping_nat64 = ""
        self.sesn_event_dslite = ""
        self.sesn_event_nat44 = ""
        self.netflow_v5 = ""
        self.port_mapping_dslite = ""
        self.port_mapping_nat44 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PortReservation(A10BaseClass):
    
    """Class Description::
    Set Port Reservations.

    Class port-reservation supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param inside_port_start: {"description": "Inside Start Port", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param nat_port_start: {"description": "NAT Start Port", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param inside_port_end: {"description": "Inside End Port", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param inside: {"optional": false, "type": "string", "description": "Inside User Address and Port Range (Inside User IP address)", "format": "ipv4-address"}
    :param nat: {"optional": false, "type": "string", "description": "NAT IP address", "format": "ipv4-address"}
    :param nat_port_end: {"description": "NAT End Port", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lsn/port-reservation/{inside}+{inside_port_start}+{inside_port_end}+{nat}+{nat_port_start}+{nat_port_end}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "inside","inside_port_start","inside_port_end","nat","nat_port_start","nat_port_end"]

        self.b_key = "port-reservation"
        self.a10_url="/axapi/v3/cgnv6/lsn/port-reservation/{inside}+{inside_port_start}+{inside_port_end}+{nat}+{nat_port_start}+{nat_port_end}"
        self.DeviceProxy = ""
        self.inside_port_start = ""
        self.nat_port_start = ""
        self.inside_port_end = ""
        self.inside = ""
        self.nat = ""
        self.nat_port_end = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class MultipleGeoLocations(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param geo_location: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify the geographic location of the GSLB site (Specify geo-location for this site)", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "multiple-geo-locations"
        self.DeviceProxy = ""
        self.geo_location = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Site(A10BaseClass):
    
    """Class Description::
    Specify a GSLB site.

    Class site supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ip_server_list: {"minItems": 1, "items": {"type": "ip-server"}, "uniqueItems": true, "array": [{"required": ["ip-server-name"], "properties": {"ip-server-name": {"description": "Specify the real server name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/gslb/service-ip"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/ip-server/{ip-server-name}"}
    :param weight: {"description": "Specify a weight for the GSLB site (Weight, default is 1)", "format": "number", "default": 1, "optional": true, "maximum": 100, "minimum": 1, "type": "number"}
    :param site_name: {"description": "Specify GSLB site name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param slb_dev_list: {"minItems": 1, "items": {"type": "slb-dev"}, "uniqueItems": true, "array": [{"required": ["device-name"], "properties": {"client-ip": {"optional": true, "type": "string", "description": "Specify client IP address", "format": "ipv4-address"}, "vip-server": {"type": "object", "properties": {"vip-server-v4-list": {"minItems": 1, "items": {"type": "vip-server-v4"}, "uniqueItems": true, "array": [{"required": ["ipv4"], "properties": {"ipv4": {"optional": false, "type": "string", "description": "Specify IP address", "format": "ipv4-address"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/slb-dev/{device-name}/vip-server/vip-server-v4/{ipv4}"}, "vip-server-v6-list": {"minItems": 1, "items": {"type": "vip-server-v6"}, "uniqueItems": true, "array": [{"required": ["ipv6"], "properties": {"ipv6": {"optional": false, "type": "string", "description": "Specify IP address (IPv6 address)", "format": "ipv6-address"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/slb-dev/{device-name}/vip-server/vip-server-v6/{ipv6}"}, "vip-server-name-list": {"minItems": 1, "items": {"type": "vip-server-name"}, "uniqueItems": true, "array": [{"required": ["vip-name"], "properties": {"vip-name": {"description": "Specify a VIP name for the SLB device", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/gslb/service-ip"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/slb-dev/{device-name}/vip-server/vip-server-name/{vip-name}"}}}, "device-name": {"description": "Specify SLB device name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "proto-aging-fast": {"default": 1, "optional": true, "type": "number", "description": "Fast GSLB Protocol aging", "format": "flag"}, "proto-compatible": {"default": 0, "optional": true, "type": "number", "description": "Run GSLB Protocol in compatible mode", "format": "flag"}, "auto-map": {"default": 1, "optional": true, "type": "number", "description": "Enable DNS Auto Mapping", "format": "flag"}, "proto-aging-time": {"description": "Specify GSLB Protocol aging time, default is 60", "format": "number", "default": 60, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "rdt-value": {"description": "Specify Round-delay-time", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "admin-preference": {"description": "Specify administrative preference (Specify admin-preference value,default is 100)", "format": "number", "default": 100, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}, "ip-address": {"optional": true, "type": "string", "description": "IP address", "format": "ipv4-address"}, "auto-detect": {"description": "'ip': Service IP only; 'port': Service Port only; 'ip-and-port': Both service IP and service port; 'disabled': disable auto-detect; ", "format": "enum", "default": "ip-and-port", "type": "string", "enum": ["ip", "port", "ip-and-port", "disabled"], "optional": true}, "health-check-action": {"description": "'health-check': Enable health Check; 'health-check-disable': Disable health check; ", "format": "enum", "default": "health-check", "type": "string", "enum": ["health-check", "health-check-disable"], "optional": true}, "max-client": {"description": "Specify maximum number of clients, default is 32768", "format": "number", "default": 32768, "optional": true, "maximum": 2147483647, "minimum": 1, "type": "number"}, "gateway-ip-addr": {"optional": true, "type": "string", "description": "IP address", "format": "ipv4-address"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/slb-dev/{device-name}"}
    :param bw_cost: {"default": 0, "optional": true, "type": "number", "description": "Specify cost of band-width", "format": "flag"}
    :param auto_map: {"default": 1, "optional": true, "type": "number", "description": "Enable DNS Auto Mapping", "format": "flag"}
    :param disable: {"default": 0, "optional": true, "type": "number", "description": "Disable all servers in the GSLB site", "format": "flag"}
    :param limit: {"description": "Specify the limit for bandwidth, default is unlimited", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 0, "optional": true}
    :param template: {"description": "Specify template to collect site information (Specify template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param threshold: {"description": "Specify the threshold for limit", "format": "number", "default": 0, "optional": true, "maximum": 100, "minimum": 0, "type": "number"}
    :param multiple_geo_locations: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"geo-location": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify the geographic location of the GSLB site (Specify geo-location for this site)", "format": "string"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/site/{site_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "site_name"]

        self.b_key = "site"
        self.a10_url="/axapi/v3/gslb/site/{site_name}"
        self.DeviceProxy = ""
        self.ip_server_list = []
        self.weight = ""
        self.site_name = ""
        self.slb_dev_list = []
        self.bw_cost = ""
        self.auto_map = ""
        self.disable = ""
        self.limit = ""
        self.template = ""
        self.threshold = ""
        self.multiple_geo_locations = []
        self.easy_rdt = {}
        self.active_rdt = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Global(A10BaseClass):
    
    """Class Description::
    Configure Port-Overloading Behavior.

    Class global supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param unique: {"description": "'destination-address': Allow overloading when the destination addresses is unique; 'destination-address-and-port': Allow overloading when the destination address and port 2-tuple is unique (default); ", "format": "enum", "default": "destination-address-and-port", "type": "string", "enum": ["destination-address", "destination-address-and-port"], "optional": true}
    :param allow_different_user: {"default": 0, "optional": true, "type": "number", "description": "Allow different users to overload the same port (default: disabled)", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lsn/port-overloading/global`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "global"
        self.a10_url="/axapi/v3/cgnv6/lsn/port-overloading/global"
        self.DeviceProxy = ""
        self.unique = ""
        self.allow_different_user = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SecurityAttack(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param layer_3: {"default": 0, "type": "number", "description": "drop packets with layer 3 anomaly", "format": "flag"}
    :param layer_4: {"default": 0, "type": "number", "description": "drop packets with layer 4 anomaly", "format": "flag"}
    :param security_attack: {"default": 0, "type": "number", "description": "drop packets causing security attack", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "security-attack"
        self.DeviceProxy = ""
        self.layer_3 = ""
        self.layer_4 = ""
        self.security_attack = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PacketDeformity(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param layer_4: {"default": 0, "type": "number", "description": "drop packets with layer 4 anomaly", "format": "flag"}
    :param layer_3: {"default": 0, "type": "number", "description": "drop packets with layer 3 anomaly", "format": "flag"}
    :param packet_deformity: {"default": 0, "type": "number", "description": "drop packets with deformity", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "packet-deformity"
        self.DeviceProxy = ""
        self.layer_4 = ""
        self.layer_3 = ""
        self.packet_deformity = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AnomalyDrop(A10BaseClass):
    
    """Class Description::
    Set IP anomaly drop policy.

    Class anomaly-drop supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param frag: {"default": 0, "optional": true, "type": "number", "description": "drop all fragmented packets", "format": "flag"}
    :param out_of_sequence: {"description": "out of sequence packet threshold (threshold value)", "format": "number", "type": "number", "maximum": 127, "minimum": 1, "optional": true}
    :param tcp_syn_fin: {"default": 0, "optional": true, "type": "number", "description": "drop TCP packets with both syn and fin flags set", "format": "flag"}
    :param drop_all: {"default": 0, "optional": true, "type": "number", "description": "drop all IP anomaly packets", "format": "flag"}
    :param ping_of_death: {"default": 0, "optional": true, "type": "number", "description": "drop oversize ICMP packets", "format": "flag"}
    :param tcp_no_flag: {"default": 0, "optional": true, "type": "number", "description": "drop TCP packets with no flag", "format": "flag"}
    :param zero_window: {"description": "zero window size threshold (threshold value)", "format": "number", "type": "number", "maximum": 127, "minimum": 1, "optional": true}
    :param ip_option: {"default": 0, "optional": true, "type": "number", "description": "drop packets with IP options", "format": "flag"}
    :param land_attack: {"default": 0, "optional": true, "type": "number", "description": "drop IP packets with the same source and destination addresses", "format": "flag"}
    :param tcp_syn_frag: {"default": 0, "optional": true, "type": "number", "description": "drop fragmented TCP packets with syn flag set", "format": "flag"}
    :param bad_content: {"description": "bad content threshold (threshold value)", "format": "number", "type": "number", "maximum": 127, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/anomaly-drop`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "anomaly-drop"
        self.a10_url="/axapi/v3/ip/anomaly-drop"
        self.DeviceProxy = ""
        self.frag = ""
        self.out_of_sequence = ""
        self.tcp_syn_fin = ""
        self.drop_all = ""
        self.ping_of_death = ""
        self.security_attack = {}
        self.tcp_no_flag = ""
        self.packet_deformity = {}
        self.zero_window = ""
        self.ip_option = ""
        self.land_attack = ""
        self.tcp_syn_frag = ""
        self.bad_content = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class BypassIpCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param bypass_ip: {"type": "string", "description": "ip address to bypass external service", "format": "ipv4-address"}
    :param mask: {"type": "string", "description": "IP prefix mask", "format": "ipv4-netmask"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "bypass-ip-cfg"
        self.DeviceProxy = ""
        self.bypass_ip = ""
        self.mask = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ExternalService(A10BaseClass):
    
    """Class Description::
    External service template.

    Class external-service supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "External Service Template Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param source_ip: {"description": "Source IP persistence template (Source IP persistence template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/persist/source-ip"}
    :param service_group: {"description": "Bind a Service Group to the template (Service Group Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}
    :param bypass_ip_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "bypass-ip": {"type": "string", "description": "ip address to bypass external service", "format": "ipv4-address"}, "mask": {"type": "string", "description": "IP prefix mask", "format": "ipv4-netmask"}}}]}
    :param failure_action: {"optional": true, "enum": ["continue", "drop", "reset"], "type": "string", "description": "'continue': Continue; 'drop': Drop; 'reset': Reset; ", "format": "enum"}
    :param timeout: {"description": "timeout value 1 - 200 in units of 200ms, default is 5 (default is 1000ms) (1 - 200 in units of 200ms, default is 5 (1000ms))", "format": "number", "default": 5, "optional": true, "maximum": 200, "minimum": 1, "type": "number"}
    :param tcp_proxy: {"description": "TCP proxy template (TCP proxy template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/slb/template/tcp-proxy"}
    :param action: {"description": "'continue': Continue; 'drop': Drop; 'reset': Reset; ", "format": "enum", "default": "continue", "type": "string", "enum": ["continue", "drop", "reset"], "optional": true}
    :param type: {"description": "'skyfire-icap': Skyfire ICAP service; 'url-filter': URL filtering service; ", "format": "enum", "default": "url-filter", "type": "string", "enum": ["skyfire-icap", "url-filter"], "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/external-service/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "external-service"
        self.a10_url="/axapi/v3/slb/template/external-service/{name}"
        self.DeviceProxy = ""
        self.name = ""
        self.source_ip = ""
        self.service_group = ""
        self.bypass_ip_cfg = []
        self.failure_action = ""
        self.timeout = ""
        self.tcp_proxy = ""
        self.action = ""
        self.A10WW_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Distance(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ext_routes_dist: {"description": "Distance for routes external to the AS", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param src_prefix: {"type": "string", "description": "IP source prefix", "format": "ipv4-cidr"}
    :param int_routes_dist: {"description": "Distance for routes internal to the AS", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param acl_str: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Access list name", "format": "string"}
    :param admin_distance: {"description": "Define an administrative distance", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param local_routes_dist: {"description": "Distance for local routes", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "distance"
        self.DeviceProxy = ""
        self.ext_routes_dist = ""
        self.src_prefix = ""
        self.int_routes_dist = ""
        self.acl_str = ""
        self.admin_distance = ""
        self.local_routes_dist = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AggregateAddressList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param as_set: {"default": 0, "type": "number", "description": "Generate AS set path information", "format": "flag"}
    :param summary_only: {"default": 0, "type": "number", "description": "Filter more specific routes from updates", "format": "flag"}
    :param aggregate_address: {"type": "string", "description": "Configure BGP aggregate entries (Aggregate prefix)", "format": "ipv4-cidr"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "aggregate-address-list"
        self.DeviceProxy = ""
        self.as_set = ""
        self.summary_only = ""
        self.aggregate_address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DampeningCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dampening_max_supress: {"description": "Maximum duration to suppress a stable route(minutes)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param dampening: {"default": 0, "type": "number", "description": "Enable route-flap dampening", "format": "flag"}
    :param route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Route-map to specify criteria for dampening (Route-map name)", "format": "string"}
    :param dampening_penalty: {"description": "Un-reachability Half-life time for the penalty(minutes)", "minimum": 1, "type": "number", "maximum": 45, "format": "number"}
    :param dampening_half_time: {"description": "Reachability Half-life time for the penalty(minutes)", "minimum": 1, "type": "number", "maximum": 45, "format": "number"}
    :param dampening_supress: {"description": "Value to start suppressing a route", "minimum": 1, "type": "number", "maximum": 20000, "format": "number"}
    :param dampening_reuse: {"description": "Value to start reusing a route", "minimum": 1, "type": "number", "maximum": 20000, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dampening-cfg"
        self.DeviceProxy = ""
        self.dampening_max_supress = ""
        self.dampening = ""
        self.route_map = ""
        self.dampening_penalty = ""
        self.dampening_half_time = ""
        self.dampening_supress = ""
        self.dampening_reuse = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class BestpathCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ignore: {"default": 0, "type": "number", "description": "Ignore as-path length in selecting a route", "format": "flag"}
    :param remove_send_med: {"default": 0, "type": "number", "description": "To remove send MED attribute", "format": "flag"}
    :param remove_recv_med: {"default": 0, "type": "number", "description": "To remove rcvd MED attribute", "format": "flag"}
    :param compare_routerid: {"default": 0, "type": "number", "description": "Compare router-id for identical EBGP paths", "format": "flag"}
    :param missing_as_worst: {"default": 0, "type": "number", "description": "Treat missing MED as the least preferred one", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "bestpath-cfg"
        self.DeviceProxy = ""
        self.ignore = ""
        self.remove_send_med = ""
        self.remove_recv_med = ""
        self.compare_routerid = ""
        self.missing_as_worst = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Bgp(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param enforce_first_as: {"default": 0, "type": "number", "description": "Enforce the first AS for EBGP routes", "format": "flag"}
    :param scan_time: {"description": "Configure background scan interval (Scan interval (sec) [Default:60 Disable:0])", "format": "number", "default": 60, "maximum": 60, "minimum": 0, "type": "number"}
    :param router_id: {"type": "string", "description": "Override current router identifier (peers will reset) (Manually configured router identifier)", "format": "ipv4-address"}
    :param log_neighbor_changes: {"default": 0, "type": "number", "description": "Log neighbor up/down and reset reason", "format": "flag"}
    :param deterministic_med: {"default": 0, "type": "number", "description": "Pick the best-MED path among paths advertised from the neighboring AS", "format": "flag"}
    :param fast_external_failover: {"default": 1, "type": "number", "description": "Immediately reset session if a link to a directly connected external peer goes down", "format": "flag"}
    :param local_preference_value: {"description": "Configure default local preference value", "format": "number", "default": 100, "maximum": 4294967295, "minimum": 0, "type": "number"}
    :param nexthop_trigger_count: {"description": "BGP nexthop-tracking status (count)", "format": "number", "default": 0, "maximum": 127, "minimum": 0, "type": "number"}
    :param always_compare_med: {"default": 0, "type": "number", "description": "Allow comparing MED from different neighbors", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "bgp"
        self.DeviceProxy = ""
        self.enforce_first_as = ""
        self.scan_time = ""
        self.router_id = ""
        self.log_neighbor_changes = ""
        self.deterministic_med = ""
        self.fast_external_failover = ""
        self.local_preference_value = ""
        self.nexthop_trigger_count = ""
        self.dampening_cfg = {}
        self.always_compare_med = ""
        self.bestpath_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Timers(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param bgp_holdtime: {"description": "Holdtime", "format": "number", "default": 90, "maximum": 65535, "minimum": 0, "type": "number"}
    :param bgp_keepalive: {"description": "Keepalive interval", "format": "number", "default": 30, "maximum": 65535, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "timers"
        self.DeviceProxy = ""
        self.bgp_holdtime = ""
        self.bgp_keepalive = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Bgp(A10BaseClass):
    
    """Class Description::
    Border Gateway Protocol (BGP).

    Class bgp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param originate: {"default": 0, "optional": true, "type": "number", "description": "Distribute a default route", "format": "flag"}
    :param aggregate_address_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"as-set": {"default": 0, "type": "number", "description": "Generate AS set path information", "format": "flag"}, "summary-only": {"default": 0, "type": "number", "description": "Filter more specific routes from updates", "format": "flag"}, "optional": true, "aggregate-address": {"type": "string", "description": "Configure BGP aggregate entries (Aggregate prefix)", "format": "ipv4-cidr"}}}]}
    :param as_number: {"description": "AS number", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 1, "optional": false}
    :param auto_summary: {"default": 0, "optional": true, "type": "number", "description": "Enable automatic network number summarization", "format": "flag"}
    :param maximum_paths_value: {"description": "Supported BGP multipath numbers", "format": "number", "default": 1, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}
    :param synchronization: {"default": 0, "optional": true, "type": "number", "description": "Perform IGP synchronization", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/bgp/{as_number}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "as_number"]

        self.b_key = "bgp"
        self.a10_url="/axapi/v3/router/bgp/{as_number}"
        self.DeviceProxy = ""
        self.distance = {}
        self.redistribute = {}
        self.originate = ""
        self.aggregate_address_list = []
        self.as_number = ""
        self.auto_summary = ""
        self.bgp = {}
        self.maximum_paths_value = ""
        self.synchronization = ""
        self.timers = {}
        self.neighbor = {}
        self.address_family = {}
        self.network = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Isis(A10BaseClass):
    
    """Class Description::
    IS-IS Routing for IP.

    Class isis supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param tag: {"description": "ISO routing area tag", "format": "string", "minLength": 1, "modify-not-allowed": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/loopback/{ifnum}/ip/router/isis`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "isis"
        self.a10_url="/axapi/v3/interface/loopback/{ifnum}/ip/router/isis"
        self.DeviceProxy = ""
        self.tag = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class VlanList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param vlan_start: {"$ref": "/axapi/v3/network/vlan", "type": "number", "description": "VLAN id", "format": "number"}
    :param vlan_end: {"type": "number", "description": "VLAN id", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "vlan-list"
        self.DeviceProxy = ""
        self.vlan_start = ""
        self.vlan_end = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class BridgeVlanGroup(A10BaseClass):
    
    """Class Description::
    Bridge VLAN Group Settings.

    Class bridge-vlan-group supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ve: {"description": "Virtual Ethernet Port (Virtual Ethernet Port number)", "format": "number", "type": "number", "maximum": 4094, "minimum": 2, "optional": true}
    :param vlan_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "vlan-start": {"$ref": "/axapi/v3/network/vlan", "type": "number", "description": "VLAN id", "format": "number"}, "vlan-end": {"type": "number", "description": "VLAN id", "format": "number"}}}]}
    :param forward_traffic: {"description": "'forward-all-traffic': Forward all traffic between bridge members; 'forward-ip-traffic': Forward only IP traffic between bridge members (default); ", "format": "enum", "default": "forward-ip-traffic", "type": "string", "enum": ["forward-all-traffic", "forward-ip-traffic"], "optional": true}
    :param bridge_vlan_group_number: {"description": "Bridge VLAN Group Number", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": false}
    :param name: {"description": "Bridge Group Name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/network/bridge-vlan-group/{bridge_vlan_group_number}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "bridge_vlan_group_number"]

        self.b_key = "bridge-vlan-group"
        self.a10_url="/axapi/v3/network/bridge-vlan-group/{bridge_vlan_group_number}"
        self.DeviceProxy = ""
        self.ve = ""
        self.vlan_list = []
        self.forward_traffic = ""
        self.bridge_vlan_group_number = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class LocalDevice(A10BaseClass):
    
    """Class Description::
    Local device configuration.

    Class local-device supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param acos_scaleout_rev_mac: {"optional": true, "type": "string", "format": "mac-address"}
    :param acos_scaleout_mac: {"optional": true, "type": "string", "format": "mac-address"}
    :param priority: {"optional": true, "minimum": 1, "type": "number", "maximum": 255, "format": "number"}
    :param acos_scaleout_ip: {"optional": true, "type": "string", "format": "ipv4-address"}
    :param acos_scaleout_rev_ip: {"optional": true, "type": "string", "format": "ipv4-address"}
    :param id: {"optional": true, "minimum": 1, "type": "number", "maximum": 64, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/acos-scaleout/local-device`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "local-device"
        self.a10_url="/axapi/v3/acos-scaleout/local-device"
        self.DeviceProxy = ""
        self.acos_scaleout_rev_mac = ""
        self.acos_scaleout_mac = ""
        self.priority = ""
        self.acos_scaleout_ip = ""
        self.acos_scaleout_rev_ip = ""
        self.A10WW_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SynCookie(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param threshold: {"description": "SYN cookie expire threshold (seconds (default is 4))", "format": "number", "default": 4, "maximum": 100, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "syn-cookie"
        self.DeviceProxy = ""
        self.threshold = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Tcp(A10BaseClass):
    
    """Class Description::
    Global TCP parameters.

    Class tcp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/tcp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "tcp"
        self.a10_url="/axapi/v3/ip/tcp"
        self.DeviceProxy = ""
        self.syn_cookie = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Nat46Stateless(A10BaseClass):
    
    """Class Description::
    Configure Stateless NAT46.

    Class nat46-stateless supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param static_dest_mapping_list: {"minItems": 1, "items": {"type": "static-dest-mapping"}, "uniqueItems": true, "array": [{"required": ["v4-address", "v6-address"], "properties": {"count": {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Set number of consecutive mappings (Number of mappings)", "format": "number", "optional": true, "modify-not-allowed": 1, "type": "number"}, "v6-address": {"optional": false, "type": "string", "description": "IPv6 address", "format": "ipv6-address"}, "v4-address": {"optional": false, "type": "string", "description": "IPv4 address", "format": "ipv4-address"}, "vrid": {"description": "VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "modify-not-allowed": 1, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/nat46-stateless/static-dest-mapping/{v4-address}+{v6-address}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/nat46-stateless`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "nat46-stateless"
        self.a10_url="/axapi/v3/cgnv6/nat46-stateless"
        self.DeviceProxy = ""
        self.fragmentation = {}
        self.static_dest_mapping_list = []
        self.prefix = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Gateway(A10BaseClass):
    
    """Class Description::
    VRRP-A tracking gateway.

    Class gateway supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ipv4_gateway_list: {"minItems": 1, "items": {"type": "ipv4-gateway"}, "uniqueItems": true, "array": [{"required": ["ip-address"], "properties": {"ip-address": {"optional": false, "type": "string", "description": "IP Address", "format": "ipv4-address"}, "priority-cost": {"description": "The amount the priority will decrease. help-val Priority", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "https://axapi.a10networks.com/axapi/v3/vrrp-a/vrid/{vrid-val}/tracking-options/gateway/ipv4-gateway/{ip-address}"}
    :param ipv6_gateway_list: {"minItems": 1, "items": {"type": "ipv6-gateway"}, "uniqueItems": true, "array": [{"required": ["ipv6-address"], "properties": {"ipv6-address": {"optional": false, "type": "string", "description": "IPV6 address", "format": "ipv6-address"}, "priority-cost": {"description": "The amount the priority will decrease. help-val Priority", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "https://axapi.a10networks.com/axapi/v3/vrrp-a/vrid/{vrid-val}/tracking-options/gateway/ipv6-gateway/{ipv6-address}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vrrp-a/vrid/{vrid_val}/tracking-options/gateway`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "gateway"
        self.a10_url="/axapi/v3/vrrp-a/vrid/{vrid_val}/tracking-options/gateway"
        self.DeviceProxy = ""
        self.ipv4_gateway_list = []
        self.ipv6_gateway_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param firmware_version: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param hw_code: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param hd_sec: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param hd_pri: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param copyright: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param sw_version: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param boot_from: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param plat_features: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param hw_platform: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param serial_number: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param up_time: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param current_time: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param aflex_version: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param last_config_saved_time: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.firmware_version = ""
        self.hw_code = ""
        self.hd_sec = ""
        self.hd_pri = ""
        self.A10WW_copyright = ""
        self.sw_version = ""
        self.boot_from = ""
        self.plat_features = ""
        self.hw_platform = ""
        self.serial_number = ""
        self.up_time = ""
        self.current_time = ""
        self.aflex_version = ""
        self.last_config_saved_time = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Version(A10BaseClass):
    
    """Class Description::
    Operational Status for the object version.

    Class version supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/version/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "version"
        self.a10_url="/axapi/v3/version/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class StaticDestMapping(A10BaseClass):
    
    """Class Description::
    Stateless NAT46 mapping (IPv4 <-> IPv6).

    Class static-dest-mapping supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param count: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Set number of consecutive mappings (Number of mappings)", "format": "number", "optional": true, "modify-not-allowed": 1, "type": "number"}
    :param v6_address: {"optional": false, "type": "string", "description": "IPv6 address", "format": "ipv6-address"}
    :param v4_address: {"optional": false, "type": "string", "description": "IPv4 address", "format": "ipv4-address"}
    :param vrid: {"description": "VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "modify-not-allowed": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/nat46-stateless/static-dest-mapping/{v4_address}+{v6_address}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "v4_address","v6_address"]

        self.b_key = "static-dest-mapping"
        self.a10_url="/axapi/v3/cgnv6/nat46-stateless/static-dest-mapping/{v4_address}+{v6_address}"
        self.DeviceProxy = ""
        self.count = ""
        self.v6_address = ""
        self.v4_address = ""
        self.vrid = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class View(A10BaseClass):
    
    """Class Description::
    Defines named "view" - a subset of the overall OID tree.

    Class view supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param mask: {"description": "Hex octets, separated by '.', mask of oid", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "not": "type", "type": "string"}
    :param oid: {"description": "MIB view family name or oid", "format": "string", "minLength": 1, "optional": false, "maxLength": 31, "type": "string"}
    :param type: {"description": "'included': MIB family is included in the view; 'excluded': MIB family is excluded from the view; ", "format": "enum", "type": "string", "enum": ["included", "excluded"], "not": "mask", "optional": true}
    :param viewname: {"description": "Name of the view", "format": "string", "minLength": 1, "optional": false, "maxLength": 31, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server/view/{viewname}+{oid}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "viewname","oid"]

        self.b_key = "view"
        self.a10_url="/axapi/v3/snmp-server/view/{viewname}+{oid}"
        self.DeviceProxy = ""
        self.mask = ""
        self.oid = ""
        self.A10WW_type = ""
        self.viewname = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Logging(A10BaseClass):
    
    """Class Description::
    System logging configuration.

    Class logging supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param single_priority_list: {"minItems": 1, "items": {"type": "single-priority"}, "uniqueItems": true, "array": [{"required": ["levelname"], "properties": {"levelname": {"optional": false, "enum": ["emergency", "alert", "critical", "error", "warning", "notification", "information", "debugging"], "type": "string", "description": "'emergency': System unusable log messages      (severity=0); 'alert': Action must be taken immediately  (severity=1); 'critical': Critical conditions               (severity=2); 'error': Error conditions                  (severity=3); 'warning': Warning conditions                (severity=4); 'notification': Normal but significant conditions (severity=5); 'information': Informational messages            (severity=6); 'debugging': Debug level messages              (severity=7); ", "format": "enum"}}}], "type": "array", "$ref": "/axapi/v3/logging/single-priority/{levelname}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/logging`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "logging"
        self.a10_url="/axapi/v3/logging"
        self.DeviceProxy = ""
        self.buffered = {}
        self.email_address = {}
        self.console = {}
        self.monitor = {}
        self.facility = {}
        self.disable_partition_name = {}
        self.email = {}
        self.syslog = {}
        self.host = {}
        self.export = {}
        self.trap = {}
        self.auditlog = {}
        self.single_priority_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class UserList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param status: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param priviledge: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param lock_time: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param unlock_time: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param trusted_host: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param partition: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param access_type: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param password: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param gui_role: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param lock_status: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param password_type: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param user_name: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "user-list"
        self.DeviceProxy = ""
        self.status = ""
        self.priviledge = ""
        self.lock_time = ""
        self.unlock_time = ""
        self.trusted_host = ""
        self.partition = ""
        self.access_type = ""
        self.password = ""
        self.gui_role = ""
        self.lock_status = ""
        self.password_type = ""
        self.user_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param user_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"status": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "priviledge": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "lock_time": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "unlock_time": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "trusted_host": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true, "partition": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "access_type": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "password": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "gui_role": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "lock_status": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "password_type": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "user_name": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.user_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AdminDetail(A10BaseClass):
    
    """Class Description::
    Operational Status for the object admin-detail.

    Class admin-detail supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/admin-detail/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "admin-detail"
        self.a10_url="/axapi/v3/admin-detail/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Domain(A10BaseClass):
    
    """Class Description::
    sixrd Domain.

    Class domain supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ipv6_prefix: {"optional": true, "type": "string", "description": "IPv6 prefix", "format": "ipv6-address-plen"}
    :param name: {"description": "6rd Domain name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param mtu: {"description": "Tunnel MTU", "format": "number", "type": "number", "maximum": 1480, "minimum": 1280, "optional": true}
    :param ce_ipv4_netmask: {"optional": true, "type": "string", "description": "Mask length", "format": "ipv4-netmask-brief"}
    :param ce_ipv4_network: {"optional": true, "type": "string", "description": "Customer Edge IPv4 network", "format": "ipv4-address"}
    :param br_ipv4_address: {"optional": true, "type": "string", "description": "6rd BR IPv4 address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/sixrd/domain/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "domain"
        self.a10_url="/axapi/v3/cgnv6/sixrd/domain/{name}"
        self.DeviceProxy = ""
        self.ipv6_prefix = ""
        self.name = ""
        self.mtu = ""
        self.ce_ipv4_netmask = ""
        self.ce_ipv4_network = ""
        self.br_ipv4_address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SessionList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Session_id: {"type": "number", "format": "number"}
    :param TTL_in_seconds: {"type": "number", "format": "number"}
    :param Domain: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Client_IP: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Domain_Group: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param VIP: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param User: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param VPort: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Type: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Created_Time: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "session-list"
        self.DeviceProxy = ""
        self.Session_id = ""
        self.TTL_in_seconds = ""
        self.Domain = ""
        self.Client_IP = ""
        self.Domain_Group = ""
        self.VIP = ""
        self.User = ""
        self.VPort = ""
        self.Type = ""
        self.Created_Time = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param session_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"Session-id": {"type": "number", "format": "number"}, "TTL-in-seconds": {"type": "number", "format": "number"}, "Domain": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Client-IP": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true, "Domain-Group": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "VIP": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "User": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "VPort": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Type": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "Created-Time": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.session_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Session(A10BaseClass):
    
    """Class Description::
    Operational Status for the object session.

    Class session supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/session/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "session"
        self.a10_url="/axapi/v3/aam/authentication/session/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dslite_data_session_freed: {"description": "DS-Lite Data Sessions Freed", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param nat64_eim_match: {"description": "NAT64 Endpoint-Independent-Mapping Matched", "format": "counter", "type": "number", "oid": "41", "optional": true, "size": "8"}
    :param total_icmp_freed: {"description": "Total ICMP Ports Freed", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param nat64_udp_alg_fullcone_created: {"description": "NAT64 UDP ALG Full-Cone Created", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "8"}
    :param fullcone_failure: {"description": "Full-Cone Session Creation Failed", "format": "counter", "type": "number", "oid": "39", "optional": true, "size": "8"}
    :param nat44_eim_match: {"description": "NAT44 Endpoint-Independent-Mapping Matched", "format": "counter", "type": "number", "oid": "40", "optional": true, "size": "8"}
    :param nat44_tcp_fullcone_created: {"description": "NAT44 TCP Full-Cone Created", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param nat44_eif_match: {"description": "NAT44 Endpoint-Independent-Filtering Matched", "format": "counter", "type": "number", "oid": "43", "optional": true, "size": "8"}
    :param nat64_data_session_created: {"description": "NAT64 Data Sessions Created", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param nat64_eif_match: {"description": "NAT64 Endpoint-Independent-Filtering Matched", "format": "counter", "type": "number", "oid": "44", "optional": true, "size": "8"}
    :param nat44_hairpin: {"description": "NAT44 Hairpin Session Created", "format": "counter", "type": "number", "oid": "52", "optional": true, "size": "8"}
    :param total_icmp_allocated: {"description": "Total ICMP Ports Allocated", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param nat64_udp_fullcone_freed: {"description": "NAT64 UDP Full-Cone Freed", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "8"}
    :param total_tcp_freed: {"description": "Total TCP Ports Freed", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param dest_rlist_snat_drop: {"description": "Fixed NAT Dest Rules List Source NAT Drop", "format": "counter", "type": "number", "oid": "60", "optional": true, "size": "8"}
    :param nat44_udp_alg_fullcone_freed: {"description": "NAT44 UDP ALG Full-Cone Freed", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param dslite_tcp_fullcone_freed: {"description": "DS-Lite TCP Full-Cone Freed", "format": "counter", "type": "number", "oid": "34", "optional": true, "size": "8"}
    :param 6rd_drop: {"description": "Fixed NAT IPv6 in IPv4 Packet Drop", "format": "counter", "type": "number", "oid": "57", "optional": true, "size": "8"}
    :param nat64_inbound_filtered: {"description": "NAT64 Endpoint-Dependent Filtering Drop", "format": "counter", "type": "number", "oid": "47", "optional": true, "size": "8"}
    :param dslite_hairpin: {"description": "DS-Lite Hairpin Session Created", "format": "counter", "type": "number", "oid": "54", "optional": true, "size": "8"}
    :param nat44_udp_alg_fullcone_created: {"description": "NAT44 UDP ALG Full-Cone Created", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param nat_port_unavailable_udp: {"description": "UDP NAT Port Unavailable", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param nat64_tcp_fullcone_created: {"description": "NAT64 TCP Full-Cone Created", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "8"}
    :param dest_rlist_pass_through: {"description": "Fixed NAT Dest Rule List Pass-Through", "format": "counter", "type": "number", "oid": "59", "optional": true, "size": "8"}
    :param nat64_tcp_fullcone_freed: {"description": "NAT64 TCP Full-Cone Freed", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "8"}
    :param dslite_udp_fullcone_created: {"description": "DS-Lite UDP Full-Cone Created", "format": "counter", "type": "number", "oid": "35", "optional": true, "size": "8"}
    :param total_udp_freed: {"description": "Total UDP Ports Freed", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param nat44_eif_limit_exceeded: {"description": "NAT44 Endpoint-Independent-Filtering Limit Exceeded", "format": "counter", "type": "number", "oid": "49", "optional": true, "size": "8"}
    :param dslite_udp_alg_fullcone_created: {"description": "DS-Lite UDP ALG Full-Cone Created", "format": "counter", "type": "number", "oid": "37", "optional": true, "size": "8"}
    :param total_tcp_allocated: {"description": "Total TCP Ports Allocated", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param nat64_udp_fullcone_created: {"description": "NAT64 UDP Full-Cone Created", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "8"}
    :param nat44_tcp_fullcone_freed: {"description": "NAT44 TCP Full-Cone Freed", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param dslite_tcp_fullcone_created: {"description": "DS-Lite TCP Full-Cone Created", "format": "counter", "type": "number", "oid": "33", "optional": true, "size": "8"}
    :param dslite_inbound_filtered: {"description": "DS-Lite Endpoint-Dependent Filtering Drop", "format": "counter", "type": "number", "oid": "48", "optional": true, "size": "8"}
    :param nat44_udp_fullcone_created: {"description": "NAT44 UDP Full-Cone Created", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param nat_port_unavailable_tcp: {"description": "TCP NAT Port Unavailable", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param nat_port_unavailable_icmp: {"description": "ICMP NAT Port Unavailable", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param nat44_data_session_created: {"description": "NAT44 Data Sessions Created", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param nat44_inbound_filtered: {"description": "NAT44 Endpoint-Dependent Filtering Drop", "format": "counter", "type": "number", "oid": "46", "optional": true, "size": "8"}
    :param nat64_hairpin: {"description": "NAT64 Hairpin Session Created", "format": "counter", "type": "number", "oid": "53", "optional": true, "size": "8"}
    :param total_nat_in_use: {"description": "Total NAT Addresses in-use", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param dslite_data_session_created: {"description": "DS-Lite Data Sessions Created", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param nat64_eif_limit_exceeded: {"description": "NAT64 Endpoint-Independent-Filtering Limit Exceeded", "format": "counter", "type": "number", "oid": "50", "optional": true, "size": "8"}
    :param nat64_data_session_freed: {"description": "NAT64 Data Sessions Freed", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param standby_drop: {"description": "Fixed NAT LID Standby Drop", "format": "counter", "type": "number", "oid": "55", "optional": true, "size": "8"}
    :param dslite_udp_fullcone_freed: {"description": "DS-Lite UDP Full-Cone Freed", "format": "counter", "type": "number", "oid": "36", "optional": true, "size": "8"}
    :param fixed_nat_fullcone_self_hairpinning_drop: {"description": "Self-Hairpinning Drop", "format": "counter", "type": "number", "oid": "56", "optional": true, "size": "8"}
    :param dslite_eim_match: {"description": "DS-Lite Endpoint-Independent-Mapping Matched", "format": "counter", "type": "number", "oid": "42", "optional": true, "size": "8"}
    :param total_udp_allocated: {"description": "Total UDP Ports Allocated", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param dslite_udp_alg_fullcone_freed: {"description": "DS-Lite UDP ALG Full-Cone Freed", "format": "counter", "type": "number", "oid": "38", "optional": true, "size": "8"}
    :param dest_rlist_drop: {"description": "Fixed NAT Dest Rule List Drop", "format": "counter", "type": "number", "oid": "58", "optional": true, "size": "8"}
    :param nat64_udp_alg_fullcone_freed: {"description": "NAT64 UDP ALG Full-Cone Freed", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "8"}
    :param session_user_quota_exceeded: {"description": "Sessions User Quota Exceeded", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param dslite_eif_limit_exceeded: {"description": "DS-Lite Endpoint-Independent-Filtering Limit Exceeded", "format": "counter", "type": "number", "oid": "51", "optional": true, "size": "8"}
    :param dslite_eif_match: {"description": "DS-Lite Endpoint-Independent-Filtering Matched", "format": "counter", "type": "number", "oid": "45", "optional": true, "size": "8"}
    :param nat44_data_session_freed: {"description": "NAT44 Data Sessions Freed", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param nat44_udp_fullcone_freed: {"description": "NAT44 UDP Full-Cone Freed", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.dslite_data_session_freed = ""
        self.nat64_eim_match = ""
        self.total_icmp_freed = ""
        self.nat64_udp_alg_fullcone_created = ""
        self.fullcone_failure = ""
        self.nat44_eim_match = ""
        self.nat44_tcp_fullcone_created = ""
        self.nat44_eif_match = ""
        self.nat64_data_session_created = ""
        self.nat64_eif_match = ""
        self.nat44_hairpin = ""
        self.total_icmp_allocated = ""
        self.nat64_udp_fullcone_freed = ""
        self.total_tcp_freed = ""
        self.dest_rlist_snat_drop = ""
        self.nat44_udp_alg_fullcone_freed = ""
        self.dslite_tcp_fullcone_freed = ""
        self.A10WW_6rd_drop = ""
        self.nat64_inbound_filtered = ""
        self.dslite_hairpin = ""
        self.nat44_udp_alg_fullcone_created = ""
        self.nat_port_unavailable_udp = ""
        self.nat64_tcp_fullcone_created = ""
        self.dest_rlist_pass_through = ""
        self.nat64_tcp_fullcone_freed = ""
        self.dslite_udp_fullcone_created = ""
        self.total_udp_freed = ""
        self.nat44_eif_limit_exceeded = ""
        self.dslite_udp_alg_fullcone_created = ""
        self.total_tcp_allocated = ""
        self.nat64_udp_fullcone_created = ""
        self.nat44_tcp_fullcone_freed = ""
        self.dslite_tcp_fullcone_created = ""
        self.dslite_inbound_filtered = ""
        self.nat44_udp_fullcone_created = ""
        self.nat_port_unavailable_tcp = ""
        self.nat_port_unavailable_icmp = ""
        self.nat44_data_session_created = ""
        self.nat44_inbound_filtered = ""
        self.nat64_hairpin = ""
        self.total_nat_in_use = ""
        self.dslite_data_session_created = ""
        self.nat64_eif_limit_exceeded = ""
        self.nat64_data_session_freed = ""
        self.standby_drop = ""
        self.dslite_udp_fullcone_freed = ""
        self.fixed_nat_fullcone_self_hairpinning_drop = ""
        self.dslite_eim_match = ""
        self.total_udp_allocated = ""
        self.dslite_udp_alg_fullcone_freed = ""
        self.dest_rlist_drop = ""
        self.nat64_udp_alg_fullcone_freed = ""
        self.session_user_quota_exceeded = ""
        self.dslite_eif_limit_exceeded = ""
        self.dslite_eif_match = ""
        self.nat44_data_session_freed = ""
        self.nat44_udp_fullcone_freed = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Global(A10BaseClass):
    
    """Class Description::
    Statistics for the object global.

    Class global supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/fixed-nat/global/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "global"
        self.a10_url="/axapi/v3/cgnv6/fixed-nat/global/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class RateLimit(A10BaseClass):
    
    """Class Description::
    Rate limit configuration.

    Class rate-limit supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param maxPktNum: {"description": "Max number of packets", "format": "number", "default": 10000, "optional": true, "maximum": 100000, "minimum": 1000, "type": "number"}
    :param rl_type: {"optional": true, "enum": ["ctrl"], "type": "string", "description": "'ctrl': The max number of packets that can be sent to kernel in 100ms; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/rate-limit`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "rate-limit"
        self.a10_url="/axapi/v3/rate-limit"
        self.DeviceProxy = ""
        self.maxPktNum = ""
        self.rl_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SslExpireCheck(A10BaseClass):
    
    """Class Description::
    SSL certificate expiration check.

    Class ssl-expire-check supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param expire_address1: {"description": "Email address for certificate expiration check", "format": "email-addr", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param interval_days: {"description": "The interval of days notice after expiration, default is 2", "format": "number", "default": 2, "optional": true, "maximum": 5, "minimum": 1, "type": "number"}
    :param ssl_expire_email_address: {"description": "Config Email address for certificate expiration check", "format": "email-addr", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param before: {"description": "The number of days in advance notice before expiration, default is 5", "format": "number", "default": 5, "optional": true, "maximum": 60, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/ssl-expire-check`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ssl-expire-check"
        self.a10_url="/axapi/v3/slb/ssl-expire-check"
        self.DeviceProxy = ""
        self.expire_address1 = ""
        self.interval_days = ""
        self.exception = {}
        self.ssl_expire_email_address = ""
        self.before = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AdminLockout(A10BaseClass):
    
    """Class Description::
    Admin user lockout configuration.

    Class admin-lockout supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param duration: {"description": "Admin user lockout duration, in minutes, by default 10 (Admin user lockout duration in minutes, 0 means forever)", "format": "number", "default": 10, "optional": true, "maximum": 1440, "minimum": 0, "type": "number"}
    :param threshold: {"description": "Admin user lockout threshold, by default 5", "format": "number", "default": 5, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}
    :param enable: {"default": 0, "optional": true, "type": "number", "description": "Enable admin user lockout", "format": "flag"}
    :param reset_time: {"description": "After how long to reset the lockout counter, in minutes, by default 10 (Time in minutes after which to reset the lockout counter)", "format": "number", "default": 10, "optional": true, "maximum": 1440, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/admin-lockout`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "admin-lockout"
        self.a10_url="/axapi/v3/admin-lockout"
        self.DeviceProxy = ""
        self.duration = ""
        self.threshold = ""
        self.enable = ""
        self.reset_time = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param inechoreps: {"description": "In Echo replies", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "2"}
    :param outaddrmaskreps: {"description": "Out Address Mask Rep", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "2"}
    :param outtimestampreps: {"description": "Out Time Stamp Rep", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "2"}
    :param inechos: {"description": "In Echo requests", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "2"}
    :param num: {"description": "Total number", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "2"}
    :param intimestampreps: {"description": "In Timestamp Rep", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "2"}
    :param outechos: {"description": "Out Echo Requests", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "2"}
    :param inaddrmasks: {"description": "In Address Masks", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "2"}
    :param outsrcquenchs: {"description": "Out Source Quench Error", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "2"}
    :param inerrors: {"description": "In Errors", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "2"}
    :param inaddrmaskreps: {"description": "In Address Mask Rep", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "2"}
    :param outmsgs: {"description": "Out Message", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "2"}
    :param outtimestamps: {"description": "Out Time Stamp", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "2"}
    :param outaddrmasks: {"description": "Out Address Mask", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "2"}
    :param inparmprobs: {"description": "In Parameter Problem", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "2"}
    :param insrcquenchs: {"description": "In Source Quench Error", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "2"}
    :param inredirects: {"description": "In Redirects", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "2"}
    :param outerrors: {"description": "Out Errors", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "2"}
    :param inmsgs: {"description": "In Messages", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "2"}
    :param outtimeexcds: {"description": "Out TTL Exceeds", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "2"}
    :param outredirects: {"description": "Out Redirects", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "2"}
    :param indestunreachs: {"description": "In Destination Unreachable", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "2"}
    :param intimeexcds: {"description": "In TTL Exceeds", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "2"}
    :param outparmprobs: {"description": "Out Parameter Problem", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "2"}
    :param intimestamps: {"description": "In Timestamp", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "2"}
    :param outechoreps: {"description": "Out Echo Replies", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "2"}
    :param outdestunreachs: {"description": "Out Destination Unreachable", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "2"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.inechoreps = ""
        self.outaddrmaskreps = ""
        self.outtimestampreps = ""
        self.inechos = ""
        self.num = ""
        self.intimestampreps = ""
        self.outechos = ""
        self.inaddrmasks = ""
        self.outsrcquenchs = ""
        self.inerrors = ""
        self.inaddrmaskreps = ""
        self.outmsgs = ""
        self.outtimestamps = ""
        self.outaddrmasks = ""
        self.inparmprobs = ""
        self.insrcquenchs = ""
        self.inredirects = ""
        self.outerrors = ""
        self.inmsgs = ""
        self.outtimeexcds = ""
        self.outredirects = ""
        self.indestunreachs = ""
        self.intimeexcds = ""
        self.outparmprobs = ""
        self.intimestamps = ""
        self.outechoreps = ""
        self.outdestunreachs = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Icmp(A10BaseClass):
    
    """Class Description::
    Statistics for the object icmp.

    Class icmp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/system/icmp/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "icmp"
        self.a10_url="/axapi/v3/system/icmp/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param curr_req: {"optional": true, "size": "8", "type": "number", "oid": "10", "format": "counter"}
    :param total_fwd_bytes: {"optional": true, "size": "8", "type": "number", "oid": "2", "format": "counter"}
    :param peak_conn: {"optional": true, "size": "8", "type": "number", "oid": "13", "format": "counter"}
    :param total_req: {"optional": true, "size": "8", "type": "number", "oid": "11", "format": "counter"}
    :param total_conn: {"optional": true, "size": "8", "type": "number", "oid": "6", "format": "counter"}
    :param fastest_rsp_time: {"optional": true, "size": "8", "type": "number", "oid": "15", "format": "counter"}
    :param total_fwd_pkts: {"optional": true, "size": "8", "type": "number", "oid": "3", "format": "counter"}
    :param total_rev_pkts_inspected_status_code_non_5xx: {"optional": true, "size": "8", "type": "number", "oid": "9", "format": "counter"}
    :param total_rev_pkts: {"optional": true, "size": "8", "type": "number", "oid": "5", "format": "counter"}
    :param total_rev_pkts_inspected_status_code_2xx: {"optional": true, "size": "8", "type": "number", "oid": "8", "format": "counter"}
    :param total_req_succ: {"optional": true, "size": "8", "type": "number", "oid": "12", "format": "counter"}
    :param curr_conn: {"optional": true, "size": "8", "type": "number", "oid": "1", "format": "counter"}
    :param total_rev_pkts_inspected: {"optional": true, "size": "8", "type": "number", "oid": "7", "format": "counter"}
    :param total_rev_bytes: {"optional": true, "size": "8", "type": "number", "oid": "4", "format": "counter"}
    :param slowest_rsp_time: {"optional": true, "size": "8", "type": "number", "oid": "16", "format": "counter"}
    :param response_time: {"optional": true, "size": "8", "type": "number", "oid": "14", "format": "counter"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.curr_req = ""
        self.total_fwd_bytes = ""
        self.peak_conn = ""
        self.total_req = ""
        self.total_conn = ""
        self.fastest_rsp_time = ""
        self.total_fwd_pkts = ""
        self.total_rev_pkts_inspected_status_code_non_5xx = ""
        self.total_rev_pkts = ""
        self.total_rev_pkts_inspected_status_code_2xx = ""
        self.total_req_succ = ""
        self.curr_conn = ""
        self.total_rev_pkts_inspected = ""
        self.total_rev_bytes = ""
        self.slowest_rsp_time = ""
        self.response_time = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Member(A10BaseClass):
    
    """Class Description::
    Statistics for the object member.

    Class member supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "Member name", "format": "comp-string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 127, "type": "string"}
    :param port: {"description": "Port number", "format": "number", "default": 65534, "optional": false, "oid": "1002", "maximum": 65534, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/service-group/{name}/member/{name}+{port}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name","port"]

        self.b_key = "member"
        self.a10_url="/axapi/v3/cgnv6/service-group/{name}/member/{name}+{port}/stats"
        self.DeviceProxy = ""
        self.stats = {}
        self.name = ""
        self.port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ip_other_block_alloc: {"optional": true, "size": "8", "type": "number", "oid": "17", "format": "counter"}
    :param entry_match_drop: {"optional": true, "size": "8", "type": "number", "oid": "6", "format": "counter"}
    :param ip_port_block_free: {"optional": true, "size": "8", "type": "number", "oid": "15", "format": "counter"}
    :param ip_node_alloc_failure: {"optional": true, "size": "8", "type": "number", "oid": "13", "format": "counter"}
    :param entry_list_alloc_failure: {"optional": true, "size": "8", "type": "number", "oid": "10", "format": "counter"}
    :param ip_node_alloc: {"optional": true, "size": "8", "type": "number", "oid": "11", "format": "counter"}
    :param entry_added_shadow: {"optional": true, "size": "8", "type": "number", "oid": "20", "format": "counter"}
    :param ip_port_block_alloc_failure: {"optional": true, "size": "8", "type": "number", "oid": "16", "format": "counter"}
    :param ip_other_block_alloc_failure: {"optional": true, "size": "8", "type": "number", "oid": "19", "format": "counter"}
    :param entry_removed_from_hw: {"optional": true, "size": "8", "type": "number", "oid": "4", "format": "counter"}
    :param entry_deleted: {"optional": true, "size": "8", "type": "number", "oid": "2", "format": "counter"}
    :param entry_list_alloc: {"optional": true, "size": "8", "type": "number", "oid": "8", "format": "counter"}
    :param entry_list_free: {"optional": true, "size": "8", "type": "number", "oid": "9", "format": "counter"}
    :param entry_added_to_hw: {"optional": true, "size": "8", "type": "number", "oid": "3", "format": "counter"}
    :param ip_node_free: {"optional": true, "size": "8", "type": "number", "oid": "12", "format": "counter"}
    :param entry_added: {"optional": true, "size": "8", "type": "number", "oid": "1", "format": "counter"}
    :param ip_other_block_free: {"optional": true, "size": "8", "type": "number", "oid": "18", "format": "counter"}
    :param entry_invalidated: {"optional": true, "size": "8", "type": "number", "oid": "21", "format": "counter"}
    :param ip_port_block_alloc: {"optional": true, "size": "8", "type": "number", "oid": "14", "format": "counter"}
    :param entry_match_drop_hw: {"optional": true, "size": "8", "type": "number", "oid": "7", "format": "counter"}
    :param hw_out_of_entries: {"optional": true, "size": "8", "type": "number", "oid": "5", "format": "counter"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.ip_other_block_alloc = ""
        self.entry_match_drop = ""
        self.ip_port_block_free = ""
        self.ip_node_alloc_failure = ""
        self.entry_list_alloc_failure = ""
        self.ip_node_alloc = ""
        self.entry_added_shadow = ""
        self.ip_port_block_alloc_failure = ""
        self.ip_other_block_alloc_failure = ""
        self.entry_removed_from_hw = ""
        self.entry_deleted = ""
        self.entry_list_alloc = ""
        self.entry_list_free = ""
        self.entry_added_to_hw = ""
        self.ip_node_free = ""
        self.entry_added = ""
        self.ip_other_block_free = ""
        self.entry_invalidated = ""
        self.ip_port_block_alloc = ""
        self.entry_match_drop_hw = ""
        self.hw_out_of_entries = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DdosProtection(A10BaseClass):
    
    """Class Description::
    Statistics for the object ddos-protection.

    Class ddos-protection supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/ddos-protection/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ddos-protection"
        self.a10_url="/axapi/v3/cgnv6/ddos-protection/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class HdCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param sec: {"default": 0, "type": "number", "description": "Secondary image", "format": "flag"}
    :param pri: {"default": 0, "type": "number", "description": "Primary image", "format": "flag"}
    :param hd: {"default": 0, "type": "number", "description": "Hard disk", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "hd-cfg"
        self.DeviceProxy = ""
        self.sec = ""
        self.pri = ""
        self.hd = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CfCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param cf_pri: {"default": 0, "type": "number", "description": "Primary image", "format": "flag"}
    :param cf: {"default": 0, "type": "number", "description": "Compact flash", "plat-neg-list": ["soft-ax"], "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "cf-cfg"
        self.DeviceProxy = ""
        self.cf_pri = ""
        self.cf = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Bootimage(A10BaseClass):
    
    """    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Set next Boot Image.

    Class bootimage supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/bootimage`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "bootimage"
        self.a10_url="/axapi/v3/bootimage"
        self.DeviceProxy = ""
        self.hd_cfg = {}
        self.cf_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


